#!/bin/bash
# Write DHCP configuration for NICs which are not defined

# This is script is intended to be executed at boot time.
# On 14.04 and later, this should be executed via udev
# For 12.04 it is executed via /etc/init/network-conf-ethX.conf

interface=${1:?arg1 must be an interface name}
fpath_d="/run/network/interfaces.ephemeral.d"
fpath="${fpath_d}/${interface}.cfg"
logger="/usr/bin/logger -t ephemeral-${interface}"
nic_opts=""

# Read the iSCSI root device information. This may or may not be used
if test -f /run/initramfs/open-iscsi.interface; then
    iscsi_iface=$(< /run/initramfs/open-iscsi.interface)
else
    iscsi_iface=$(ls /sys/firmware/ibft/ethernet*/device/net/)
fi

if [ "${iscsi_iface}" = "${interface}" ]; then
        ${logger} "${interface} was configured via initramfs for iSCSI root. Device is unmanaged."
        exit 0
fi

if ! test -d ${fpath_d}; then
    mkdir -p ${fpath_d}
    ${logger} "created ${fpath_d} for ephemeral NIC definition"
fi

# We need the following because 12.04 doesn't use exit codes on ifquery
# when the NIC is not there.
create_flag=$(/sbin/ifquery ${interface} 2>&1 \
                 | awk '{s=tolower($0)} s~/unknown/ {print"CREATE"}')

if [ "${create_flag:-NO}" = "CREATE" ]; then
   printf "auto %s\niface %s inet dhcp\n%s\n" \
            ${interface} ${interface} ${nic_opts} \
            > ${fpath}
   ${logger} "per-boot dhcp configuration written for ${fpath}"
else
   # Don't create the device if the device has been already configured
   ${logger} "device ${interface} has been configured already"
fi
